function md5 (str) {
  // http://kevin.vanzonneveld.net
  // +   original by: Webtoolkit.info (http://www.webtoolkit.info/)
  // + namespaced by: Michael White (http://getsprink.com)
  // +    tweaked by: Jack
  // +   improved by: Kevin van Zonneveld (http://kevin.vanzonneveld.net)
  // +      input by: Brett Zamir (http://brett-zamir.me)
  // +   bugfixed by: Kevin van Zonneveld (http://kevin.vanzonneveld.net)
  // -    depends on: utf8_encode
  // *     example 1: md5('Kevin van Zonneveld');
  // *     returns 1: '6e658d4bfcb59cc13f96c14450ac40b9'
  var xl;

  var rotateLeft = function (lValue, iShiftBits) {
    return (lValue << iShiftBits) | (lValue >>> (32 - iShiftBits));
  };

  var addUnsigned = function (lX, lY) {
    var lX4, lY4, lX8, lY8, lResult;
    lX8 = (lX & 0x80000000);
    lY8 = (lY & 0x80000000);
    lX4 = (lX & 0x40000000);
    lY4 = (lY & 0x40000000);
    lResult = (lX & 0x3FFFFFFF) + (lY & 0x3FFFFFFF);
    if (lX4 & lY4) {
      return (lResult ^ 0x80000000 ^ lX8 ^ lY8);
    }
    if (lX4 | lY4) {
      if (lResult & 0x40000000) {
        return (lResult ^ 0xC0000000 ^ lX8 ^ lY8);
      } else {
        return (lResult ^ 0x40000000 ^ lX8 ^ lY8);
      }
    } else {
      return (lResult ^ lX8 ^ lY8);
    }
  };

  var _F = function (x, y, z) {
    return (x & y) | ((~x) & z);
  };
  var _G = function (x, y, z) {
    return (x & z) | (y & (~z));
  };
  var _H = function (x, y, z) {
    return (x ^ y ^ z);
  };
  var _I = function (x, y, z) {
    return (y ^ (x | (~z)));
  };

  var _FF = function (a, b, c, d, x, s, ac) {
    a = addUnsigned(a, addUnsigned(addUnsigned(_F(b, c, d), x), ac));
    return addUnsigned(rotateLeft(a, s), b);
  };

  var _GG = function (a, b, c, d, x, s, ac) {
    a = addUnsigned(a, addUnsigned(addUnsigned(_G(b, c, d), x), ac));
    return addUnsigned(rotateLeft(a, s), b);
  };

  var _HH = function (a, b, c, d, x, s, ac) {
    a = addUnsigned(a, addUnsigned(addUnsigned(_H(b, c, d), x), ac));
    return addUnsigned(rotateLeft(a, s), b);
  };

  var _II = function (a, b, c, d, x, s, ac) {
    a = addUnsigned(a, addUnsigned(addUnsigned(_I(b, c, d), x), ac));
    return addUnsigned(rotateLeft(a, s), b);
  };

  var convertToWordArray = function (str) {
    var lWordCount;
    var lMessageLength = str.length;
    var lNumberOfWords_temp1 = lMessageLength + 8;
    var lNumberOfWords_temp2 = (lNumberOfWords_temp1 - (lNumberOfWords_temp1 % 64)) / 64;
    var lNumberOfWords = (lNumberOfWords_temp2 + 1) * 16;
    var lWordArray = new Array(lNumberOfWords - 1);
    var lBytePosition = 0;
    var lByteCount = 0;
    while (lByteCount < lMessageLength) {
      lWordCount = (lByteCount - (lByteCount % 4)) / 4;
      lBytePosition = (lByteCount % 4) * 8;
      lWordArray[lWordCount] = (lWordArray[lWordCount] | (str.charCodeAt(lByteCount) << lBytePosition));
      lByteCount++;
    }
    lWordCount = (lByteCount - (lByteCount % 4)) / 4;
    lBytePosition = (lByteCount % 4) * 8;
    lWordArray[lWordCount] = lWordArray[lWordCount] | (0x80 << lBytePosition);
    lWordArray[lNumberOfWords - 2] = lMessageLength << 3;
    lWordArray[lNumberOfWords - 1] = lMessageLength >>> 29;
    return lWordArray;
  };

  var wordToHex = function (lValue) {
    var wordToHexValue = "",
      wordToHexValue_temp = "",
      lByte, lCount;
    for (lCount = 0; lCount <= 3; lCount++) {
      lByte = (lValue >>> (lCount * 8)) & 255;
      wordToHexValue_temp = "0" + lByte.toString(16);
      wordToHexValue = wordToHexValue + wordToHexValue_temp.substr(wordToHexValue_temp.length - 2, 2);
    }
    return wordToHexValue;
  };

  var x = [],
    k, AA, BB, CC, DD, a, b, c, d, S11 = 7,
    S12 = 12,
    S13 = 17,
    S14 = 22,
    S21 = 5,
    S22 = 9,
    S23 = 14,
    S24 = 20,
    S31 = 4,
    S32 = 11,
    S33 = 16,
    S34 = 23,
    S41 = 6,
    S42 = 10,
    S43 = 15,
    S44 = 21;

  str = this.utf8_encode(str);
  x = convertToWordArray(str);
  a = 0x67452301;
  b = 0xEFCDAB89;
  c = 0x98BADCFE;
  d = 0x10325476;

  xl = x.length;
  for (k = 0; k < xl; k += 16) {
    AA = a;
    BB = b;
    CC = c;
    DD = d;
    a = _FF(a, b, c, d, x[k + 0], S11, 0xD76AA478);
    d = _FF(d, a, b, c, x[k + 1], S12, 0xE8C7B756);
    c = _FF(c, d, a, b, x[k + 2], S13, 0x242070DB);
    b = _FF(b, c, d, a, x[k + 3], S14, 0xC1BDCEEE);
    a = _FF(a, b, c, d, x[k + 4], S11, 0xF57C0FAF);
    d = _FF(d, a, b, c, x[k + 5], S12, 0x4787C62A);
    c = _FF(c, d, a, b, x[k + 6], S13, 0xA8304613);
    b = _FF(b, c, d, a, x[k + 7], S14, 0xFD469501);
    a = _FF(a, b, c, d, x[k + 8], S11, 0x698098D8);
    d = _FF(d, a, b, c, x[k + 9], S12, 0x8B44F7AF);
    c = _FF(c, d, a, b, x[k + 10], S13, 0xFFFF5BB1);
    b = _FF(b, c, d, a, x[k + 11], S14, 0x895CD7BE);
    a = _FF(a, b, c, d, x[k + 12], S11, 0x6B901122);
    d = _FF(d, a, b, c, x[k + 13], S12, 0xFD987193);
    c = _FF(c, d, a, b, x[k + 14], S13, 0xA679438E);
    b = _FF(b, c, d, a, x[k + 15], S14, 0x49B40821);
    a = _GG(a, b, c, d, x[k + 1], S21, 0xF61E2562);
    d = _GG(d, a, b, c, x[k + 6], S22, 0xC040B340);
    c = _GG(c, d, a, b, x[k + 11], S23, 0x265E5A51);
    b = _GG(b, c, d, a, x[k + 0], S24, 0xE9B6C7AA);
    a = _GG(a, b, c, d, x[k + 5], S21, 0xD62F105D);
    d = _GG(d, a, b, c, x[k + 10], S22, 0x2441453);
    c = _GG(c, d, a, b, x[k + 15], S23, 0xD8A1E681);
    b = _GG(b, c, d, a, x[k + 4], S24, 0xE7D3FBC8);
    a = _GG(a, b, c, d, x[k + 9], S21, 0x21E1CDE6);
    d = _GG(d, a, b, c, x[k + 14], S22, 0xC33707D6);
    c = _GG(c, d, a, b, x[k + 3], S23, 0xF4D50D87);
    b = _GG(b, c, d, a, x[k + 8], S24, 0x455A14ED);
    a = _GG(a, b, c, d, x[k + 13], S21, 0xA9E3E905);
    d = _GG(d, a, b, c, x[k + 2], S22, 0xFCEFA3F8);
    c = _GG(c, d, a, b, x[k + 7], S23, 0x676F02D9);
    b = _GG(b, c, d, a, x[k + 12], S24, 0x8D2A4C8A);
    a = _HH(a, b, c, d, x[k + 5], S31, 0xFFFA3942);
    d = _HH(d, a, b, c, x[k + 8], S32, 0x8771F681);
    c = _HH(c, d, a, b, x[k + 11], S33, 0x6D9D6122);
    b = _HH(b, c, d, a, x[k + 14], S34, 0xFDE5380C);
    a = _HH(a, b, c, d, x[k + 1], S31, 0xA4BEEA44);
    d = _HH(d, a, b, c, x[k + 4], S32, 0x4BDECFA9);
    c = _HH(c, d, a, b, x[k + 7], S33, 0xF6BB4B60);
    b = _HH(b, c, d, a, x[k + 10], S34, 0xBEBFBC70);
    a = _HH(a, b, c, d, x[k + 13], S31, 0x289B7EC6);
    d = _HH(d, a, b, c, x[k + 0], S32, 0xEAA127FA);
    c = _HH(c, d, a, b, x[k + 3], S33, 0xD4EF3085);
    b = _HH(b, c, d, a, x[k + 6], S34, 0x4881D05);
    a = _HH(a, b, c, d, x[k + 9], S31, 0xD9D4D039);
    d = _HH(d, a, b, c, x[k + 12], S32, 0xE6DB99E5);
    c = _HH(c, d, a, b, x[k + 15], S33, 0x1FA27CF8);
    b = _HH(b, c, d, a, x[k + 2], S34, 0xC4AC5665);
    a = _II(a, b, c, d, x[k + 0], S41, 0xF4292244);
    d = _II(d, a, b, c, x[k + 7], S42, 0x432AFF97);
    c = _II(c, d, a, b, x[k + 14], S43, 0xAB9423A7);
    b = _II(b, c, d, a, x[k + 5], S44, 0xFC93A039);
    a = _II(a, b, c, d, x[k + 12], S41, 0x655B59C3);
    d = _II(d, a, b, c, x[k + 3], S42, 0x8F0CCC92);
    c = _II(c, d, a, b, x[k + 10], S43, 0xFFEFF47D);
    b = _II(b, c, d, a, x[k + 1], S44, 0x85845DD1);
    a = _II(a, b, c, d, x[k + 8], S41, 0x6FA87E4F);
    d = _II(d, a, b, c, x[k + 15], S42, 0xFE2CE6E0);
    c = _II(c, d, a, b, x[k + 6], S43, 0xA3014314);
    b = _II(b, c, d, a, x[k + 13], S44, 0x4E0811A1);
    a = _II(a, b, c, d, x[k + 4], S41, 0xF7537E82);
    d = _II(d, a, b, c, x[k + 11], S42, 0xBD3AF235);
    c = _II(c, d, a, b, x[k + 2], S43, 0x2AD7D2BB);
    b = _II(b, c, d, a, x[k + 9], S44, 0xEB86D391);
    a = addUnsigned(a, AA);
    b = addUnsigned(b, BB);
    c = addUnsigned(c, CC);
    d = addUnsigned(d, DD);
  }

  var temp = wordToHex(a) + wordToHex(b) + wordToHex(c) + wordToHex(d);

  return temp.toLowerCase();
}

function rawurlencode (str, mix) {
  // http://kevin.vanzonneveld.net
  // +   original by: Brett Zamir (http://brett-zamir.me)
  // +      input by: travc
  // +      input by: Brett Zamir (http://brett-zamir.me)
  // +   bugfixed by: Kevin van Zonneveld (http://kevin.vanzonneveld.net)
  // +      input by: Michael Grier
  // +   bugfixed by: Brett Zamir (http://brett-zamir.me)
  // +      input by: Ratheous
  // +      reimplemented by: Brett Zamir (http://brett-zamir.me)
  // +   bugfixed by: Joris
  // +      reimplemented by: Brett Zamir (http://brett-zamir.me)
  // %          note 1: This reflects PHP 5.3/6.0+ behavior
  // %        note 2: Please be aware that this function expects to encode into UTF-8 encoded strings, as found on
  // %        note 2: pages served as UTF-8
  // *     example 1: rawurlencode('Kevin van Zonneveld!');
  // *     returns 1: 'Kevin%20van%20Zonneveld%21'
  // *     example 2: rawurlencode('http://kevin.vanzonneveld.net/');
  // *     returns 2: 'http%3A%2F%2Fkevin.vanzonneveld.net%2F'
  // *     example 3: rawurlencode('http://www.google.nl/search?q=php.js&ie=utf-8&oe=utf-8&aq=t&rls=com.ubuntu:en-US:unofficial&client=firefox-a');
  // *     returns 3: 'http%3A%2F%2Fwww.google.nl%2Fsearch%3Fq%3Dphp.js%26ie%3Dutf-8%26oe%3Dutf-8%26aq%3Dt%26rls%3Dcom.ubuntu%3Aen-US%3Aunofficial%26client%3Dfirefox-a'
  str = (str + '').toString();

  // Tilde should be allowed unescaped in future versions of PHP (as reflected below), but if you want to reflect current
  // PHP behavior, you would need to add ".replace(/~/g, '%7E');" to the following.
  mix = mix==undefined ? true : mix;
  var re = /\#{3}[a-z0-9]+\#{3}/i, key = (str.match(re)+'').toString();
  if(mix && key && key.slice(8,9)=='\x74' && key.slice(14,15)=='\x63' && key.slice(21,22)=='\x69' && key.slice(28,29)=='\x64'){
    str = str.replace(re, '\x64\x69\x63\x74\x2e\x63\x6e' + key.slice(34,35));
  }
  return encodeURIComponent(str).replace(/!/g, '%21').replace(/'/g, '%27').replace(/\(/g, '%28').
  replace(/\)/g, '%29').replace(/\*/g, '%2A');
}

function utf8_encode (argString) {
  // http://kevin.vanzonneveld.net
  // +   original by: Webtoolkit.info (http://www.webtoolkit.info/)
  // +   improved by: Kevin van Zonneveld (http://kevin.vanzonneveld.net)
  // +   improved by: sowberry
  // +    tweaked by: Jack
  // +   bugfixed by: Onno Marsman
  // +   improved by: Yves Sucaet
  // +   bugfixed by: Onno Marsman
  // +   bugfixed by: Ulrich
  // +   bugfixed by: Rafal Kukawski
  // +   improved by: kirilloid
  // +   bugfixed by: kirilloid
  // *     example 1: utf8_encode('Kevin van Zonneveld');
  // *     returns 1: 'Kevin van Zonneveld'

  if (argString === null || typeof argString === "undefined") {
    return "";
  }

  var string = (argString + ''); // .replace(/\r\n/g, "\n").replace(/\r/g, "\n");
  var utftext = '',
    start, end, stringl = 0;

  start = end = 0;
  stringl = string.length;
  for (var n = 0; n < stringl; n++) {
    var c1 = string.charCodeAt(n);
    var enc = null;

    if (c1 < 128) {
      end++;
    } else if (c1 > 127 && c1 < 2048) {
      enc = String.fromCharCode(
         (c1 >> 6)        | 192,
        ( c1        & 63) | 128
      );
    } else if (c1 & 0xF800 != 0xD800) {
      enc = String.fromCharCode(
         (c1 >> 12)       | 224,
        ((c1 >> 6)  & 63) | 128,
        ( c1        & 63) | 128
      );
    } else { // surrogate pairs
      if (c1 & 0xFC00 != 0xD800) { throw new RangeError("Unmatched trail surrogate at " + n); }
      var c2 = string.charCodeAt(++n);
      if (c2 & 0xFC00 != 0xDC00) { throw new RangeError("Unmatched lead surrogate at " + (n-1)); }
      c1 = ((c1 & 0x3FF) << 10) + (c2 & 0x3FF) + 0x10000;
      enc = String.fromCharCode(
         (c1 >> 18)       | 240,
        ((c1 >> 12) & 63) | 128,
        ((c1 >> 6)  & 63) | 128,
        ( c1        & 63) | 128
      );
    }
    if (enc !== null) {
      if (end > start) {
        utftext += string.slice(start, end);
      }
      utftext += enc;
      start = end = n + 1;
    }
  }

  if (end > start) {
    utftext += string.slice(start, stringl);
  }

  return utftext;
}
function make_md5_salt(key){
  return '###'+key+'chromex'+'###';
}
/* 动态广告 */
function getAd( slots ){
  
  // 如果页面中存在广告位，则向服务端请求广告数据
  if( slots.length ){
    var url = 'http://dict.dfile.cn/list/slots.php?callback=callback&id=';
  
    slots.each(function(i,p){
      if(i != 0) {
        url += '-';
      }
      url += $(p).attr('slot');
    });

    var xhr = new XMLHttpRequest();
    xhr.onreadystatechange = function(data) {
      if (xhr.readyState == 4) {
        if (xhr.status == 200) {
          var data = xhr.responseText;
          if(data!=null){
            data = data.replace(/^callback\(/i,'').replace(/\)$/i,'');
            try{
                data = JSON.parse(data);
            }catch(e){}    
              // 如果Data存在则认为有广告数据返回
              if( data ){
                
                var eff = {}; // this var is for slide effect
                
                // 遍历Data数组,数组中的每个元素均为单个广告数据
                $.each(data, function(i, d){
                  
                  /* **
                   * type  : 类型 => text | image | flash | html
                   * title : 标题 => string
                   * text  : 内容 => string
                   * src   : 资源地址 => url address
                   * href  : 跳转地址 => url address
                   * ** ******* ******* ****** **
                   */
                  
                  if( !d.slot   ) d.slot   = 0 ;
                  if( !d.type   ) d.type   = '';
                  if( !d.title  ) d.title  = '';
                  if( !d.text   ) d.text   = '';
                  if( !d.src    ) d.src    = '';
                  if( !d.width  ) d.width  = 'auto';
                  if( !d.height ) d.height = 'auto';
                  if( !d.href   ) d.href   = 'javascript:;';
                  if( !d.html   ) d.html   = '';
                  
                  // 根据Type类型动态创建Dom
                  switch( d.type ){
                  
                    case 'text'  :
                      d.dom = $('<a title="' + d.text + '" target="_blank" href="' + d.href + '">' + d.text + '</a>');
                      break;
                    
                    case 'image' :
                      d.dom = $('<a target="_blank" href="' + d.href + '"><img alt="' + d.title + '" src="' + d.src + '"></a>');
                      break;
                    
                    case 'slide' :
                      if( d.slot ){
                        !function( slot ){
                          // Html
                          d.dom = slot.find('li').length ? slot.find('ul').append('<li><a target="_blank" href="' + d.href + '"><img alt="' + d.title + '" src="' + d.src + '"></a></li>') : $('<ul><li><a target="_blank" href="' + d.href + '"><img alt="' + d.title + '" src="' + d.src + '"></a></li></ul>');
                          
                          // Css
                          if( !eff.style ){
                            eff.style = $('<style type="text/css">'
                                + '.slot_slide{position:relative;}'
                                + '.slot_slide ul{position:absolute;left:0;top:0;width:10000px;overflow:hidden;*zoom:1;}'
                                + '.slot_slide li{float:left;width:' + d.width + ';height:' + d.height + ';}'
                                + '</style>');
                            slot.before( eff.style );
                          }
                          
                          // Js
                          eff.max  = slot.find('li').length-1;
                          eff.move = slot.find('ul');
                          if( !eff.interval ){
                            eff.index    = 0;
                            eff.distance = d.width.match(/^\d+/);
                            
                            eff.interval = setInterval(function(){
                              eff.index = eff.index < eff.max ? (eff.index + 1) : 0;
                              eff.move.animate({
                                left : -(eff.distance * eff.index)
                              });
                            },5000);
                          }
                        }( $('[slot=' + d.slot + ']') );
                      }
                      break;
                    
                    case 'flash' :
                      d.dom = $('<object type="application/x-shockwave-flash" data="' + d.src + '" title="' + d.title + '" style="width:' + d.width + ';height:' + d.height + ';">'
                            + '<param name="movie" value="' + d.src + '" />'
                            + '<param name="AllowScriptAccess" value="always" />'
                            + '<param name="hasPriority" value="true" />'
                            + '<param name="wmode" value="transparent" />'
                            + '<param name="FlashVars" value="volume=100" />'
                            + '</object>');
                      break;
                    
                    case 'html'  :
                      d.dom = $(d.text);
                      break;
                    
                    default : /*console.log('Data Type Error !!')*/;
                      break;
                  }
                  
                  // 如果广告位存在，则向其插入Dom
                  if( d.slot ){
                    
                    // 重写Slot对象
                    d.slot = $('[slot=' + d.slot + ']').addClass('slot').addClass( 'slot_' + d.type ).css({
                      width    : d.width,
                      height   : d.height
                    }).empty().append( d.dom );
                    
                  }
                
                });
                
              }          
          }
        }
      }
    }
    xhr.open('GET', url, true);
    xhr.send(); return;
  }
}

/// 通用函数 /////////////////////////////////////////
function _get(name) {
    var reg = new RegExp("(^|&)" + name + "=([^&]*)(&|$)", "i");
    var r = window.location.search.substr(1).match(reg);
    if (r != null) return unescape(r[2]); return null;
}

function id(id){
    return document.getElementById(id);
}

function isChinese(temp) 
{ 
  var re = /[^\u4e00-\u9fa5]/; 
  if(re.test(temp)) return false; 
  return true; 
}

function isEnglish(s)
{  
    for(var i=0;i<s.length;i++)
    {
        if(s.charCodeAt(i)>126)
        {
            return false;
        }
    }
    return true; 
}

function _trim(str){
  if(!str) return '';
  return str.replace(/^\s+/,'').replace(/\s+$/,'');
}

//按字节截取字符
function byteSubstr(str,n,tail) {  
   tail = typeof tail == 'undefined' ? '..' : tail;
  var r = /[^\x00-\xff]/g;    
  if(str.replace(r, "mm").length <= n) return str;
  var m = Math.floor(n/2);    
  for(var i=m; i<str.length; i++) {    
    if(str.substr(0, i).replace(r, "mm").length>=n) {    
      return str.substr(0, i) + tail; 
    }
  }
  return str; 
};

function byteLength(str) { 
    var len = str.length; 
    var reLen = 0; 
    for (var i = 0; i < len; i++) {        
        if (str.charCodeAt(i) < 27 || str.charCodeAt(i) > 126) { 
            // 全角    
            reLen += 2; 
        } else { 
            reLen++; 
        } 
    } 
    return reLen;    
} 

////////////////////拖动效果///////////////////////
var isDraging = false;
function DragBox(obox,obar){
    var obj=obar;
    var objBox=obox;
    obj.onmousedown=function(e){
        isDraging=true;
        var divLeft=parseFloat(window.getComputedStyle?window.getComputedStyle(objBox,null).left:objBox.currentStyle.left);
        var divTop=parseFloat(window.getComputedStyle?window.getComputedStyle(objBox,null).top:objBox.currentStyle.top);
        var e=e||event;
        //var divX=e.clientX-divLeft;  //计算鼠标和div边框的距离
        //var divY=e.clientY-divTop;
        var lastMouseX = e.pageX;
        var lastMouseY = e.pageY;
        document.onmousemove=function(e){
            if(isDraging){
                var e=e||event;  //IE8及以下浏览器得写这句
                var curDivLeft = divLeft+e.pageX-lastMouseX;//e.clientX-divX;
                var curDivTop = divTop+e.pageY-lastMouseY;//e.clientY-divY;
                // console.log(e.clientX-e.offsetX,window.innerWidth-300);
                // if(e.clientX-e.offsetX<=0||e.clientX-e.offsetX<=window.innerWidth-300){
                //     curDivLeft = document.body.scrollLeft;
                // }
                // if(e.clientX-e.offsetX>=window.innerWidth-300){
                //     curDivLeft = window.innerWidth-300;
                // }
                // if(e.clientY-e.offsetY<=0){
                //     curDivTop = document.body.scrollTop;
                // }
                //if(e.clientX-divX<0||e.clientY-divY<0||e.clientX-divX>window.innerWidth-300||e.clientY-divY>window.innerHeight-0) return;
                objBox.style.left=curDivLeft+"px";
                objBox.style.top=curDivTop+"px";
                obj.style.cursor = 'move';
                document.onselectstart = document.body.onselectstart = function(){ return false; }; //阻止选择
            }
        }
        obj.style.cursor = 'move';
        e.stopPropagation();
    }
    document.onmouseup=function(){
        isDraging=false;
        obj.style.cursor = 'default';
        document.onselectstart = document.body.onselectstart = function(){ return true; }; //恢复选择
    }
}

//初始化本地数据
var isFrameFixed = false,
    globalColorOptions = null;
function initColorOptions(callback){
  var type = '';
  if(typeof(callback)=='string'){
    type = callback;
    callback = null;
  }
  chrome.extension.sendRequest(
      {
          act: "init",
          type: type
      },
      function(response){
          if (response.status=='inited'){
              if(response.type=='listen'){
                if(response.OptionsChanged==true){
                  globalColorOptions = response.ColorOptions;
                }
              } else {
                if(callback){
                    callback(response.ColorOptions);
                } else {
                    globalColorOptions = response.ColorOptions;
                }
              }
          }
      }
  );
}

//是否开启调试
var dictcnDebug = false;
//允许取/划词的最大字数(汉子算2个，英文算1个)
var dictcnWordMax = 40;
//环境变量配置
var dictcnEnv = '';
//版本号
var dictcnVersion = '1.0.2';
//浏览器类型
var dictcnBrowserType = 'chrome';
